@@ -1,10 +1,8 @@
 #include <R.h>
 #include <Rinternals.h>
+#include <stdlib.h>
 #include <math.h>
 
-void gutsredit_init(void (* odeparms)(int *, double *));
-void gutsredit_free(void);
-
 /**
  * Number of MCMC iterations
  */
@@ -40,9 +38,9 @@ void gutsredit_init(void (* odeparms)(int *, double *))
   MCMC = (int)REAL(fun())[0];
   // allocate memory
   int N = MCMC*2+1;
-  double *arr = (double*)Calloc(N, double);
-  kd = (double*)Calloc(MCMC, double);
-  hb = (double*)Calloc(MCMC, double);
+  double *arr = (double*)calloc(N, sizeof(double));
+  kd = (double*)calloc(MCMC, sizeof(double));
+  hb = (double*)calloc(MCMC, sizeof(double));
   // import parameters
   odeparms(&N, arr);
   // by copying the array we avoid index magic later on
@@ -50,7 +48,7 @@ void gutsredit_init(void (* odeparms)(int *, double *))
     kd[i] = arr[i+1];
     hb[i] = arr[MCMC+i+1];
   }
-  Free(arr);
+  free(arr);
 }
 
 /**
@@ -58,8 +56,8 @@ void gutsredit_init(void (* odeparms)(int *, double *))
  */
 void gutsredit_free(void)
 {
-  Free(kd);
-  Free(hb);
+  free(kd);
+  free(hb);
 }
 
 /**
